package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Dec 7, 2018
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Decode(json []byte, v interface{}) error
JsonEncode decode json bytes to data. use it instead of json.Unmarshal
JsonEncode encode data to json bytes. use it instead of json.Marshal
Pretty get pretty JSON string
func WriteFile(filePath string, data interface{}) error
WriteFile
Source Files
¶
Click to show internal directories.
Click to hide internal directories.